/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {

dojo.provide("com.ibm.rational.report.web.core.client.internal.SecurityClient");

dojo.require("com.ibm.rational.report.web.core.client.internal.SessionManager");
dojo.require("com.ibm.team.repository.web.client.session.Session");
dojo.require("com.ibm.team.repository.web.transport.ServiceRequest");
dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");
dojo.require("com.ibm.team.repository.web.transport.TeamServerClient");
dojo.require("com.ibm.team.process.web.client.projectarea");

var SessionManager			= com.ibm.rational.report.web.core.client.internal.SessionManager;
var session					= com.ibm.team.repository.web.client.session;
var ServiceRequest 			= com.ibm.team.repository.web.transport.ServiceRequest;
var ServiceResponseHandler 	= com.ibm.team.repository.web.transport.ServiceResponseHandler;
var TeamServerClient 		= com.ibm.team.repository.web.transport.TeamServerClient;

/**
 * Manages security REST service calls.
 */
com.ibm.rational.report.web.core.client.internal.SecurityClient = {

	SECURITY_SERVICE_URI: "com.ibm.rational.security.common.ISecurityRestService",
	
	REPORT_SECURITY_SERVICE_URI: "com.ibm.rational.report.common.ISecurityRestService",
	
	getAllPermissions: function(responseHandler) {
		this._invokeSecurityService(responseHandler, "getAllPermissions", null);
	},
		
	getPermissions: function(responseHandler, args) {
		this._invokeSecurityService(responseHandler, "getPermissions", args);
	},
	
	getPermission: function(responseHandler, args) {
		this._invokeSecurityService(responseHandler, "getPermission", args);
	},
	
	getPermissionCheck: function(responseHandler, args) {
		this._invokeSecurityService(responseHandler, "getPermissionCheck", args);
	},
	
	postNewPermission: function(responseHandler, args) {
		this._invokeSecurityService(responseHandler, "postNewPermission", args);
	},

	postUpdatePermission: function(responseHandler, args) {
		this._invokeSecurityService(responseHandler, "postUpdatePermission", args);
	},
	
	postDeletePermission: function(responseHandler, args) {
		this._invokeSecurityService(responseHandler, "postDeletePermission", args);
	},	

	getAllAclEntries: function(responseHandler) {
		this._invokeSecurityService(responseHandler, "getAllAclEntries", null);
	},
	
	getAclEntries: function(responseHandler, args) {
		this._invokeSecurityService(responseHandler, "getAclEntries", args);
	},
	
	getAclEntry: function(responseHandler, args) {
		this._invokeSecurityService(responseHandler, "getAclEntry", args);
	},	
	
	postNewAclEntries: function(responseHandler, args) {
		this._invokeSecurityService(responseHandler, "postNewAclEntries", args);
	},

	postUpdateAclEntry: function(responseHandler, args) {
		this._invokeSecurityService(responseHandler, "postUpdateAclEntry", args);
	},
	
	postDeleteAclEntries: function(responseHandler, args) {
		this._invokeSecurityService(responseHandler, "postDeleteAclEntries", args);
	},	
	
	postDeleteAclEntriesWithPrincipals: function(responseHandler, args) {
		this._invokeSecurityService(responseHandler, "postDeleteAclEntriesWithPrincipals", args);
	},	
	
	postDeleteAclEntriesWithRepositoryItems: function(responseHandler, args) {
		this._invokeSecurityService(responseHandler, "postDeleteAclEntriesWithRepositoryItems", args);
	},	
	
	getAllAcls: function(responseHandler) {
		this._invokeSecurityService(responseHandler, "getAllAcls", null);
	},
	
	getAcls: function(responseHandler, args) {
		this._invokeSecurityService(responseHandler, "getAcls", args);
	},
	
	getAcl: function(responseHandler, args) {
		this._invokeSecurityService(responseHandler, "getAcl", args);
	},	
	
	postNewAcl: function(responseHandler, args) {
		this._invokeSecurityService(responseHandler, "postNewAcl", args);
	},

	postUpdateAcl: function(responseHandler, args) {
		this._invokeSecurityService(responseHandler, "postUpdateAcl", args);
	},
	
	postDeleteAcl: function(responseHandler, args) {
		this._invokeSecurityService(responseHandler, "postDeleteAcl", args);
	},
	
	postDeleteAcl: function(responseHandler, args) {
		this._invokeSecurityService(responseHandler, "postDeleteAcl", args);
	},	
	
	getDataSourcePermissions: function(responseHandler) {
		this._invokeReportSecurityService(responseHandler, "getDataSourcePermissions", null);
	},
	
	getReportFolderPermissions: function(responseHandler) {
		this._invokeReportSecurityService(responseHandler, "getReportFolderPermissions", null);
	},
	
	getReportDesignPermissions: function(responseHandler) {
		this._invokeReportSecurityService(responseHandler, "getReportDesignPermissions", null);
	},
	
	getReportQueryPermissions: function(responseHandler) {
		this._invokeReportSecurityService(responseHandler, "getReportQueryPermissions", null);
	},
	
	getReportSnapshotPermissions: function(responseHandler) {
		this._invokeReportSecurityService(responseHandler, "getReportSnapshotPermissions", null);
	},
	
	/**
	 * Invokes the requested method on the security REST service.
	 */
	_invokeSecurityService: function(responseHandler, method, args) {
		if (arguments.length == 2) {
			var serviceRequest= new com.ibm.team.repository.web.transport.ServiceRequest(
					this.SECURITY_SERVICE_URI,
					method);
		} else {
			serviceRequest = new com.ibm.team.repository.web.transport.ServiceRequest(
					this.SECURITY_SERVICE_URI,
					method,
					args);
		}
		com.ibm.team.repository.web.transport.TeamServerClient.invokeService(
				serviceRequest,
				responseHandler);
		SessionManager.resetTimeOut();
	},
	
	/**
	 * Invokes the requested method on the report security REST service.
	 */
	_invokeReportSecurityService: function(responseHandler, method, args) {
		if (arguments.length == 2) {
			var serviceRequest = new com.ibm.team.repository.web.transport.ServiceRequest(
					this.REPORT_SECURITY_SERVICE_URI,
					method);
		} else {
			serviceRequest = new com.ibm.team.repository.web.transport.ServiceRequest(
					this.REPORT_SECURITY_SERVICE_URI,
					method,
					args);
		}
		com.ibm.team.repository.web.transport.TeamServerClient.invokeService(
				serviceRequest,
				responseHandler);
		SessionManager.resetTimeOut();
	}
	
};

})();